@@ -67,6 +67,7 @@ def set_wink_credentials(client_id, client_secret, refresh_token):
     response_json = response.json()
     access_token = response_json.get('access_token')
     set_bearer_token(access_token)
+    return access_token
 
 
 def get_bulbs():
@@ -93,6 +94,10 @@ def get_garage_doors():
     return get_devices(device_types.GARAGE_DOOR)
 
 
+def get_shades():
+    return get_devices(device_types.SHADE)
+
+
 def get_powerstrip_outlets():
     return get_devices(device_types.POWER_STRIP)
 
@@ -142,6 +147,8 @@ def get_devices_from_response_dict(response_dict, filter_key):
                 subsensors = _get_subsensors_from_sensor_pod(item, api_interface)
                 if subsensors:
                     devices.extend(subsensors)
+                if len(subsensors) == 1:
+                    continue
 
             devices.append(build_device(item, api_interface))
 
@@ -152,7 +159,7 @@ def _get_subsensors_from_sensor_pod(item, api_interface):
 
     capabilities = [cap['field'] for cap in item.get('capabilities', {}).get('fields', [])]
     if not capabilities:
-        return
+        return []
 
     subsensors = []
 
